@@ -1,15 +1,19 @@
 __all__ = [
     'Add',
     'Config',
+    'Execute',
     'Install',
     'List',
-    'Uninstall',
-    'Execute'
+    'Profile',
+    'Remove',
+    'Uninstall'
 ]
 
 from linux_profile.commands.add import Add
 from linux_profile.commands.config import Config
+from linux_profile.commands.execute import Execute
 from linux_profile.commands.install import Install
 from linux_profile.commands.list import List
+from linux_profile.commands.profile import Profile
+from linux_profile.commands.remove import Remove
 from linux_profile.commands.uninstall import Uninstall
-from linux_profile.commands.execute import Execute
