@@ -14,5 +14,5 @@ class Config(_Config):
 
     def setup_get(self):
         urllib.request.urlretrieve(
-            self.get, self.join([self.linuxp_path_config, self.linuxp_file_profile])
+            self.get, self.join([self.linuxp_path_config, self.linuxp_file_config])
         )
